# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/nativeact/v1/nativeact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/nativeact/v1/nativeact.proto\x12\x19\x62ilibili.app.nativeact.v1\x1a\x19google/protobuf/any.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"I\n\x04\x41rea\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x0c\n\x04ukey\x18\x05 \x01(\t\"?\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\"d\n\x0f\x43\x61rouselImgCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12:\n\x06images\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgItem\"\x90\x01\n\x0f\x43\x61rouselImgItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\x03\x12\r\n\x05width\x18\x04 \x01(\x03\x12\x32\n\x07top_tab\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\x12\x0e\n\x06height\x18\x06 \x01(\x03\"z\n\x10\x43\x61rouselWordCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12\x13\n\x0bscroll_type\x18\x02 \x01(\x03\x12:\n\x05words\x18\x03 \x03(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordItem\"#\n\x10\x43\x61rouselWordItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x91\x06\n\x05\x43olor\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x13\n\x0btitle_color\x18\x02 \x01(\t\x12\x16\n\x0etop_font_color\x18\x03 \x01(\t\x12\x19\n\x11\x62ottom_font_color\x18\x04 \x01(\t\x12\x12\n\nfont_color\x18\x05 \x01(\t\x12\x1d\n\x15text_title_font_color\x18\x06 \x01(\t\x12\x17\n\x0findicator_color\x18\x07 \x01(\t\x12\x15\n\rcard_bg_color\x18\x08 \x01(\t\x12\x1d\n\x15\x63\x61rd_title_font_color\x18\t \x01(\t\x12\x1b\n\x13\x63\x61rd_title_bg_color\x18\n \x01(\t\x12\x1c\n\x14view_more_font_color\x18\x0b \x01(\t\x12\x1a\n\x12view_more_bg_color\x18\x0c \x01(\t\x12\x16\n\x0etimeline_color\x18\r \x01(\t\x12\x17\n\x0frcmd_font_color\x18\x0e \x01(\t\x12\x1b\n\x13subtitle_font_color\x18\x0f \x01(\t\x12\x1b\n\x13selected_font_color\x18\x10 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x11 \x01(\t\x12\x1d\n\x15unselected_font_color\x18\x12 \x01(\t\x12\x1b\n\x13unselected_bg_color\x18\x13 \x01(\t\x12\x1e\n\x16nt_selected_font_color\x18\x14 \x01(\t\x12\x1c\n\x14nt_selected_bg_color\x18\x15 \x01(\t\x12 \n\x18nt_unselected_font_color\x18\x16 \x01(\t\x12\x1e\n\x16nt_unselected_bg_color\x18\x17 \x01(\t\x12\x1a\n\x12progress_bar_color\x18\x18 \x01(\t\x12\x16\n\x0epanel_bg_color\x18\x19 \x01(\t\x12\x1a\n\x12panel_select_color\x18\x1a \x01(\t\x12\x1f\n\x17panel_select_font_color\x18\x1b \x01(\t\x12\"\n\x1apanel_nt_select_font_color\x18\x1c \x01(\t\"m\n\x12\x44ynamicActMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"D\n\x0b\x44ynamicCard\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"j\n\x0f\x44ynamicMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\x84\x01\n\rDynamicParams\x12)\n\x0b\x66\x65\x65\x64_offset\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x12\n\nlast_group\x18\x03 \x01(\x03\x12\x11\n\tmodule_id\x18\x04 \x01(\x03\x12\x11\n\tsort_type\x18\x05 \x01(\x03\"\xf7\x01\n\nDynamicReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.DynamicParams\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\x07 \x01(\x03\"@\n\x0b\x44ynamicResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"1\n\x0c\x45\x64itorParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\"\xfa\x03\n\x13\x45\x64itorRecommendCard\x12\x10\n\x08top_icon\x18\x01 \x01(\t\x12\x13\n\x0btop_content\x18\x02 \x01(\t\x12\x13\n\x0b\x62ottom_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x62ottom_content\x18\x04 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x11\n\tposition1\x18\x08 \x01(\t\x12\x11\n\tposition2\x18\t \x01(\t\x12\x11\n\tposition3\x18\n \x01(\t\x12\x11\n\tposition4\x18\x0b \x01(\t\x12\x11\n\tposition5\x18\x0c \x01(\t\x12/\n\x05share\x18\r \x01(\x0b\x32 .bilibili.app.nativeact.v1.Share\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x0f \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x33\n\x07setting\x18\x10 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12\x13\n\x0bmiddle_icon\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"q\n\tEditorReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.EditorParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"?\n\nEditorResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"[\n\x0f\x46ollowOgvParams\x12\x35\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32%.bilibili.app.nativeact.v1.ActionType\x12\x11\n\tseason_id\x18\x02 \x01(\x05\"^\n\x0c\x46ollowOgvReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32*.bilibili.app.nativeact.v1.FollowOgvParams\"%\n\x0c\x46ollowOgvRly\x12\x15\n\rfollow_params\x18\x01 \x01(\t\"X\n\x08GameCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\"\xd7\x01\n\nHeaderCard\x12\x12\n\nuser_image\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x17\n\x0fsponsor_content\x18\x03 \x01(\t\x12\x18\n\x10high_light_image\x18\x04 \x01(\t\x12\x17\n\x0flow_light_image\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08view_num\x18\x07 \x01(\t\x12\x13\n\x0b\x64iscuss_num\x18\x08 \x01(\t\x12\x15\n\ris_subscribed\x18\t \x01(\x08\x12\x0b\n\x03mid\x18\n \x01(\x03\">\n\x08IconCard\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.nativeact.v1.IconItem\"5\n\x08IconItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x1f\n\x0eImageTitleCard\x12\r\n\x05image\x18\x01 \x01(\t\"\xde\x02\n\x08IndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\r \x01(\x03\x12\x10\n\x08tab_from\x18\x0e \x01(\t\"\xbc\x01\n\x0eInlineIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\"T\n\x0cLayerDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x07\x64ynamic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"R\n\x08LiveCard\x12\x10\n\x08has_live\x18\x01 \x01(\x05\x12\x34\n\x07\x63ontent\x18\x02 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveItem\"\xf9\x02\n\x08LiveItem\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x13\n\x0blive_status\x18\x03 \x01(\x03\x12\x11\n\troom_type\x18\x04 \x01(\x03\x12\x11\n\tplay_type\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x63over\x18\x07 \x01(\t\x12\x0e\n\x06online\x18\x08 \x01(\x03\x12\x0f\n\x07\x61rea_id\x18\t \x01(\x03\x12\x11\n\tarea_name\x18\n \x01(\t\x12\x16\n\x0eparent_area_id\x18\x0b \x01(\x03\x12\x18\n\x10parent_area_name\x18\x0c \x01(\t\x12\x18\n\x10live_screen_type\x18\r \x01(\x03\x12\x15\n\rlast_end_time\x18\x0e \x01(\x03\x12\x0c\n\x04link\x18\x0f \x01(\t\x12\x0f\n\x07live_id\x18\x10 \x01(\x03\x12@\n\x0cwatched_show\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.LiveWatchedShow\"{\n\x0fLiveWatchedShow\x12\x0e\n\x06switch\x18\x01 \x01(\x08\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x12\n\ntext_small\x18\x03 \x01(\t\x12\x12\n\ntext_large\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x15\n\ricon_location\x18\x06 \x01(\t\"\xba\x01\n\nMessageBox\x12\x11\n\talert_msg\x18\x01 \x01(\t\x12\x1b\n\x13\x63onfirm_button_text\x18\x02 \x01(\t\x12\x1a\n\x12\x63\x61ncel_button_text\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfirm_msg\x18\x04 \x01(\t\x12\x12\n\ncancel_msg\x18\x05 \x01(\t\x12\x37\n\x04type\x18\x06 \x01(\x0e\x32).bilibili.app.nativeact.v1.MessageBoxType\"\xb1\x02\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\x12\x36\n\x0cmodule_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12:\n\x0emodule_setting\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12;\n\x0cmodule_items\x18\x05 \x03(\x0b\x32%.bilibili.app.nativeact.v1.ModuleItem\x12\x16\n\x0esubpage_params\x18\x06 \x01(\t\x12\x13\n\x0bmodule_ukey\x18\x07 \x01(\t\x12\x10\n\x08has_more\x18\x08 \x01(\x08\x12\x0f\n\x07is_feed\x18\t \x01(\x08\"\x9c \n\nModuleItem\x12G\n\tcard_type\x18\x01 \x01(\x0e\x32\x34.bilibili.app.nativeact.v1.ModuleItem.CardDetailCase\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\t\x12O\n\x15\x65\x64itor_recommend_card\x18\n \x01(\x0b\x32..bilibili.app.nativeact.v1.EditorRecommendCardH\x00\x12J\n\x12participation_card\x18\x0b \x01(\x0b\x32,.bilibili.app.nativeact.v1.ParticipationCardH\x00\x12<\n\x0bheader_card\x18\x0c \x01(\x0b\x32%.bilibili.app.nativeact.v1.HeaderCardH\x00\x12>\n\x0c\x64ynamic_card\x18\r \x01(\x0b\x32&.bilibili.app.nativeact.v1.DynamicCardH\x00\x12\x38\n\ttext_card\x18\x0e \x01(\x0b\x32#.bilibili.app.nativeact.v1.TextCardH\x00\x12\x43\n\x0ftext_title_card\x18\x0f \x01(\x0b\x32(.bilibili.app.nativeact.v1.TextTitleCardH\x00\x12\x45\n\x10image_title_card\x18\x10 \x01(\x0b\x32).bilibili.app.nativeact.v1.ImageTitleCardH\x00\x12G\n\x11\x64ynamic_more_card\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.DynamicMoreCardH\x00\x12N\n\x15\x64ynamic_act_more_card\x18\x12 \x01(\x0b\x32-.bilibili.app.nativeact.v1.DynamicActMoreCardH\x00\x12\x38\n\tlive_card\x18\x13 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveCardH\x00\x12G\n\x11\x63\x61rousel_img_card\x18\x14 \x01(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgCardH\x00\x12I\n\x12\x63\x61rousel_word_card\x18\x15 \x01(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordCardH\x00\x12@\n\rresource_card\x18\x16 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ResourceCardH\x00\x12I\n\x12resource_more_card\x18\x17 \x01(\x0b\x32+.bilibili.app.nativeact.v1.ResourceMoreCardH\x00\x12\x38\n\tgame_card\x18\x18 \x01(\x0b\x32#.bilibili.app.nativeact.v1.GameCardH\x00\x12:\n\nvideo_card\x18\x19 \x01(\x0b\x32$.bilibili.app.nativeact.v1.VideoCardH\x00\x12\x43\n\x0fvideo_more_card\x18\x1a \x01(\x0b\x32(.bilibili.app.nativeact.v1.VideoMoreCardH\x00\x12=\n\x0erecommend_card\x18\x1b \x01(\x0b\x32#.bilibili.app.nativeact.v1.RcmdCardH\x00\x12N\n\x17recommend_vertical_card\x18\x1c \x01(\x0b\x32+.bilibili.app.nativeact.v1.RcmdVerticalCardH\x00\x12\x46\n\x10relativeact_card\x18\x1d \x01(\x0b\x32*.bilibili.app.nativeact.v1.RelativeactCardH\x00\x12U\n\x18relativeact_capsule_card\x18\x1e \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.RelativeactCapsuleCardH\x00\x12\x42\n\x0estatement_card\x18\x1f \x01(\x0b\x32(.bilibili.app.nativeact.v1.StatementCardH\x00\x12\x38\n\ticon_card\x18  \x01(\x0b\x32#.bilibili.app.nativeact.v1.IconCardH\x00\x12\x38\n\tvote_card\x18! \x01(\x0b\x32#.bilibili.app.nativeact.v1.VoteCardH\x00\x12>\n\x0creserve_card\x18\" \x01(\x0b\x32&.bilibili.app.nativeact.v1.ReserveCardH\x00\x12I\n\x12timeline_head_card\x18# \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineHeadCardH\x00\x12T\n\x18timeline_event_text_card\x18$ \x01(\x0b\x32\x30.bilibili.app.nativeact.v1.TimelineEventTextCardH\x00\x12V\n\x19timeline_event_image_card\x18% \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.TimelineEventImageCardH\x00\x12^\n\x1dtimeline_event_imagetext_card\x18& \x01(\x0b\x32\x35.bilibili.app.nativeact.v1.TimelineEventImagetextCardH\x00\x12\\\n\x1ctimeline_event_resource_card\x18\' \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineEventResourceCardH\x00\x12I\n\x12timeline_more_card\x18( \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineMoreCardH\x00\x12M\n\x14timeline_unfold_card\x18) \x01(\x0b\x32-.bilibili.app.nativeact.v1.TimelineUnfoldCardH\x00\x12=\n\x0cogv_one_card\x18* \x01(\x0b\x32%.bilibili.app.nativeact.v1.OgvOneCardH\x00\x12\x41\n\x0eogv_three_card\x18+ \x01(\x0b\x32\'.bilibili.app.nativeact.v1.OgvThreeCardH\x00\x12?\n\rogv_more_card\x18, \x01(\x0b\x32&.bilibili.app.nativeact.v1.OgvMoreCardH\x00\x12\x44\n\x0fnavigation_card\x18- \x01(\x0b\x32).bilibili.app.nativeact.v1.NavigationCardH\x00\x12:\n\nreply_card\x18. \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReplyCardH\x00\x12\x36\n\x08tab_card\x18/ \x01(\x0b\x32\".bilibili.app.nativeact.v1.TabCardH\x00\x12@\n\rnewact_header\x18\x30 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.NewactHeaderH\x00\x12>\n\x0cnewact_award\x18\x31 \x01(\x0b\x32&.bilibili.app.nativeact.v1.NewactAwardH\x00\x12\x46\n\x10newact_statement\x18\x32 \x01(\x0b\x32*.bilibili.app.nativeact.v1.NewactStatementH\x00\x12@\n\rprogress_card\x18\x33 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ProgressCardH\x00\x12<\n\x0bselect_card\x18\x34 \x01(\x0b\x32%.bilibili.app.nativeact.v1.SelectCardH\x00\"\xd6\x07\n\x0e\x43\x61rdDetailCase\x12\x16\n\x12\x43\x41RDDETAIL_NOT_SET\x10\x00\x12\x19\n\x15\x45\x44ITOR_RECOMMEND_CARD\x10\n\x12\x16\n\x12PARTICIPATION_CARD\x10\x0b\x12\x0f\n\x0bHEADER_CARD\x10\x0c\x12\x10\n\x0c\x44YNAMIC_CARD\x10\r\x12\r\n\tTEXT_CARD\x10\x0e\x12\x13\n\x0fTEXT_TITLE_CARD\x10\x0f\x12\x14\n\x10IMAGE_TITLE_CARD\x10\x10\x12\x15\n\x11\x44YNAMIC_MORE_CARD\x10\x11\x12\x19\n\x15\x44YNAMIC_ACT_MORE_CARD\x10\x12\x12\r\n\tLIVE_CARD\x10\x13\x12\x15\n\x11\x43\x41ROUSEL_IMG_CARD\x10\x14\x12\x16\n\x12\x43\x41ROUSEL_WORD_CARD\x10\x15\x12\x11\n\rRESOURCE_CARD\x10\x16\x12\x16\n\x12RESOURCE_MORE_CARD\x10\x17\x12\r\n\tGAME_CARD\x10\x18\x12\x0e\n\nVIDEO_CARD\x10\x19\x12\x13\n\x0fVIDEO_MORE_CARD\x10\x1a\x12\x12\n\x0eRECOMMEND_CARD\x10\x1b\x12\x1b\n\x17RECOMMEND_VERTICAL_CARD\x10\x1c\x12\x14\n\x10RELATIVEACT_CARD\x10\x1d\x12\x1c\n\x18RELATIVEACT_CAPSULE_CARD\x10\x1e\x12\x12\n\x0eSTATEMENT_CARD\x10\x1f\x12\r\n\tICON_CARD\x10 \x12\r\n\tVOTE_CARD\x10!\x12\x10\n\x0cRESERVE_CARD\x10\"\x12\x16\n\x12TIMELINE_HEAD_CARD\x10#\x12\x1c\n\x18TIMELINE_EVENT_TEXT_CARD\x10$\x12\x1d\n\x19TIMELINE_EVENT_IMAGE_CARD\x10%\x12!\n\x1dTIMELINE_EVENT_IMAGETEXT_CARD\x10&\x12 \n\x1cTIMELINE_EVENT_RESOURCE_CARD\x10\'\x12\x16\n\x12TIMELINE_MORE_CARD\x10(\x12\x18\n\x14TIMELINE_UNFOLD_CARD\x10)\x12\x10\n\x0cOGV_ONE_CARD\x10*\x12\x12\n\x0eOGV_THREE_CARD\x10+\x12\x11\n\rOGV_MORE_CARD\x10,\x12\x13\n\x0fNAVIGATION_CARD\x10-\x12\x0e\n\nREPLY_CARD\x10.\x12\x0c\n\x08TAB_CARD\x10/\x12\x16\n\x12NEWACT_HEADER_CARD\x10\x30\x12\x15\n\x11NEWACT_AWARD_CARD\x10\x31\x12\x19\n\x15NEWACT_STATEMENT_CARD\x10\x32\x12\x11\n\rPROGRESS_CARD\x10\x33\x12\x0f\n\x0bSELECT_CARD\x10\x34\x42\r\n\x0b\x63\x61rd_detail\"J\n\x0eNavigationCard\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32).bilibili.app.nativeact.v1.NavigationItem\"2\n\x0eNavigationItem\x12\x11\n\tmodule_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\"W\n\x0bNewactAward\x12\r\n\x05title\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.NewactAwardItem\"1\n\x0fNewactAwardItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"3\n\rNewactFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x02 \x01(\t\"\xd2\x01\n\x0cNewactHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x15\n\rsponsor_title\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x11\n\tuser_name\x18\x06 \x01(\t\x12\x11\n\tuser_face\x18\x07 \x01(\t\x12\x10\n\x08user_url\x18\x08 \x01(\t\x12:\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32(.bilibili.app.nativeact.v1.NewactFeature\"5\n\x13NewactStatementItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"_\n\x0fNewactStatement\x12\r\n\x05title\x18\x01 \x01(\t\x12=\n\x05items\x18\x02 \x03(\x0b\x32..bilibili.app.nativeact.v1.NewactStatementItem\"G\n\x0cOfficialInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\"\x95\x01\n\x0fOgvFollowButton\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\x12\x13\n\x0b\x66ollow_text\x18\x02 \x01(\t\x12\x13\n\x0b\x66ollow_icon\x18\x03 \x01(\t\x12\x15\n\runfollow_text\x18\x04 \x01(\t\x12\x15\n\runfollow_icon\x18\x05 \x01(\t\x12\x15\n\rfollow_params\x18\x06 \x01(\t\"M\n\x0bOgvMoreCard\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x19\n\x11supernatant_title\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t\"\x94\x03\n\nOgvOneCard\x12\x11\n\tposition1\x18\x01 \x01(\t\x12\x11\n\tposition2\x18\x02 \x01(\t\x12\x11\n\tposition3\x18\x03 \x01(\t\x12\x19\n\x11\x63over_right_text1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_right_text2\x18\x05 \x01(\t\x12\x14\n\x0crcmd_content\x18\x06 \x01(\t\x12\x11\n\trcmd_icon\x18\x07 \x01(\t\x12\x41\n\rfollow_button\x18\x08 \x01(\x0b\x32*.bilibili.app.nativeact.v1.OgvFollowButton\x12\r\n\x05image\x18\r \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\r\n\x05title\x18\x0f \x01(\t\x12\x38\n\nreport_dic\x18\x10 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x0b\n\x03url\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"M\n\x14OgvSupernatantParams\x12\x12\n\nlast_index\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\"\x81\x01\n\x11OgvSupernatantReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12?\n\x06params\x18\x02 \x01(\x0b\x32/.bilibili.app.nativeact.v1.OgvSupernatantParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"[\n\x12OgvSupernatantResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x12\n\nlast_index\x18\x02 \x01(\x03\"\xaa\x02\n\x0cOgvThreeCard\x12\x18\n\x10\x63over_left_text1\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x41\n\rfollow_button\x18\x03 \x01(\x0b\x32*.bilibili.app.nativeact.v1.OgvFollowButton\x12\r\n\x05image\x18\x04 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x05 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\r\n\x05title\x18\x06 \x01(\t\x12\x38\n\nreport_dic\x18\x07 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x15\n\rresource_type\x18\t \x01(\t\"\x91\x04\n\x08PageResp\x12\x11\n\tis_online\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_app_dark_theme\x18\x02 \x01(\x08\x12\x34\n\npage_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12\x38\n\npage_share\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\x12\x36\n\x0bpage_header\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x38\n\rparticipation\x18\x06 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x36\n\x0bmodule_list\x18\x07 \x03(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x17\n\x0fis_dynamic_feed\x18\x08 \x01(\x08\x12>\n\rlayer_dynamic\x18\t \x01(\x0b\x32\'.bilibili.app.nativeact.v1.LayerDynamic\x12\x16\n\x0eis_editor_feed\x18\n \x01(\x08\x12\x14\n\x0csponsor_type\x18\x0b \x01(\x03\x12\x32\n\x07top_tab\x18\x0c \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\"\xc5\x01\n\tPageShare\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x12\n\ninside_uri\x18\x05 \x01(\t\x12\x13\n\x0boutside_uri\x18\x06 \x01(\t\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x0b\n\x03sid\x18\x08 \x01(\t\x12\x16\n\x0espace_page_url\x18\t \x01(\t\x12 \n\x18space_exclusive_page_url\x18\n \x01(\t\"{\n\x11ParticipationCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0eselected_image\x18\x02 \x01(\t\x12?\n\x05items\x18\x03 \x03(\x0b\x32\x30.bilibili.app.nativeact.v1.ParticipationCardItem\"P\n\x15ParticipationCardItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"@\n\x0fPlayerDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x08\"\xae\x02\n\x0cProgressCard\x12\x37\n\x05style\x18\x01 \x01(\x0e\x32(.bilibili.app.nativeact.v1.ProgressStyle\x12:\n\tslot_type\x18\x02 \x01(\x0e\x32\'.bilibili.app.nativeact.v1.ProgressSlot\x12\x38\n\x08\x62\x61r_type\x18\x03 \x01(\x0e\x32&.bilibili.app.nativeact.v1.ProgressBar\x12\x15\n\rtexture_image\x18\x04 \x01(\t\x12\x0b\n\x03num\x18\x05 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x06 \x01(\t\x12\x36\n\x05nodes\x18\x07 \x03(\x0b\x32\'.bilibili.app.nativeact.v1.ProgressNode\"]\n\rProgressEvent\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.bilibili.app.nativeact.v1.ProgressEventItem\"x\n\x11ProgressEventItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03num\x18\x03 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x04 \x01(\t\x12\x0f\n\x07web_key\x18\x05 \x01(\t\x12\x11\n\tdimension\x18\x06 \x01(\x03\">\n\x0cProgressNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x13\n\x0b\x64isplay_num\x18\x03 \x01(\t\"\x1e\n\x0bProgressReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\"F\n\x0bProgressRly\x12\x37\n\x05\x65vent\x18\x01 \x01(\x0b\x32(.bilibili.app.nativeact.v1.ProgressEvent\"\xa4\x02\n\x08RcmdCard\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0bis_followed\x18\x06 \x01(\x08\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.OfficialInfo\x12/\n\x03vip\x18\x08 \x01(\x0b\x32\".bilibili.app.nativeact.v1.VipInfo\x12\x11\n\trank_icon\x18\t \x01(\t\x12>\n\rredirect_type\x18\n \x01(\x0e\x32\'.bilibili.app.nativeact.v1.RedirectType\"F\n\x10RcmdVerticalCard\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.bilibili.app.nativeact.v1.RcmdCard\"i\n\x16RelativeactCapsuleCard\x12\r\n\x05title\x18\x01 \x01(\t\x12@\n\x05items\x18\x02 \x03(\x0b\x32\x31.bilibili.app.nativeact.v1.RelativeactCapsuleItem\"E\n\x16RelativeactCapsuleItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"J\n\x0fRelativeactCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"+\n\tReplyCard\x12\x10\n\x08reply_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"\xa9\x01\n\tReportDic\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\t\x12\x13\n\x0bseason_type\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x10\n\x08sub_type\x18\x05 \x01(\x05\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x12\n\nis_preview\x18\x07 \x01(\x05\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x61uthor_name\x18\t \x01(\t\"\x84\x02\n\rReserveButton\x12\x34\n\x04goto\x18\x01 \x01(\x0e\x32&.bilibili.app.nativeact.v1.ReserveGoto\x12:\n\x0bmessage_box\x18\x02 \x01(\x0b\x32%.bilibili.app.nativeact.v1.MessageBox\x12\x16\n\x0ereserve_params\x18\x03 \x01(\t\x12\x10\n\x08has_done\x18\x04 \x01(\x08\x12\x11\n\tdone_text\x18\x05 \x01(\t\x12\x13\n\x0bundone_text\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x14\n\x0cis_highlight\x18\x08 \x01(\x08\x12\x0b\n\x03url\x18\t \x01(\t\"\xe3\x01\n\x0bReserveCard\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x0b\n\x03num\x18\x08 \x01(\x03\x12\x10\n\x08subtitle\x18\t \x01(\t\x12\x38\n\x06\x62utton\x18\n \x01(\x0b\x32(.bilibili.app.nativeact.v1.ReserveButton\x12\x18\n\x10hide_reserve_num\x18\x0b \x01(\x08\",\n\rReserveParams\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0b\n\x03sid\x18\x02 \x01(\x03\"Z\n\nReserveReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.ReserveParams\"$\n\nReserveRly\x12\x16\n\x0ereserve_params\x18\x01 \x01(\t\"\xc7\x02\n\x0cResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12/\n\x05\x62\x61\x64ge\x18\t \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"k\n\x10ResourceMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\\\n\x0eResourceParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"u\n\x0bResourceReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32).bilibili.app.nativeact.v1.ResourceParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"A\n\x0cResourceResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"W\n\nSelectCard\x12\x13\n\x0b\x63urrent_tab\x18\x01 \x01(\x03\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SelectItem\"f\n\nSelectItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x38\n\npage_share\x18\x03 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\"\xf3\x02\n\x07Setting\x12\x1b\n\x13\x64isplay_more_button\x18\x01 \x01(\x08\x12\x15\n\rdisplay_title\x18\x02 \x01(\x08\x12\x15\n\rauto_carousel\x18\x03 \x01(\x08\x12\x1a\n\x12top_tab_follow_img\x18\x04 \x01(\x08\x12\x19\n\x11top_tab_fade_away\x18\x05 \x01(\x08\x12\x11\n\tauto_play\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isplay_unfold_button\x18\x07 \x01(\x08\x12\x13\n\x0b\x64isplay_num\x18\x08 \x01(\x08\x12\x18\n\x10\x64isplay_view_num\x18\t \x01(\x08\x12\x1d\n\x15\x64isplay_subscribe_btn\x18\n \x01(\x08\x12\x13\n\x0bunfold_rest\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isplay_progress_num\x18\x0c \x01(\x08\x12\x18\n\x10\x64isplay_node_num\x18\r \x01(\x08\x12\x19\n\x11\x64isplay_node_desc\x18\x0e \x01(\x08\"U\n\x05Share\x12\x15\n\rdisplay_later\x18\x01 \x01(\x08\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x12\n\nshare_type\x18\x04 \x01(\x03\"9\n\tSizeImage\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05width\x18\x03 \x01(\x03\" \n\rStatementCard\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"a\n\x0bSubpageData\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\x12\x33\n\x04tabs\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SubpageTab\"*\n\nSubpageTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"\xbd\x01\n\x07TabCard\x12\x13\n\x0b\x63urrent_tab\x18\x01 \x01(\x03\x12\x32\n\x05style\x18\x02 \x01(\x0e\x32#.bilibili.app.nativeact.v1.TabStyle\x12\x31\n\x05items\x18\x03 \x03(\x0b\x32\".bilibili.app.nativeact.v1.TabItem\x12\x36\n\x08\x62g_image\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\"\xd2\x01\n\x0bTabIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x17\n\x0fprimary_page_id\x18\x05 \x01(\x03\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x15\n\ris_cold_start\x18\x07 \x01(\x08\"\xdb\x01\n\x07TabItem\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rdisable_click\x18\x03 \x01(\x08\x12\x1b\n\x13\x64isable_click_toast\x18\x04 \x01(\t\x12<\n\x0eselected_image\x18\x05 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12>\n\x10unselected_image\x18\x06 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\"\x18\n\x08TextCard\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1e\n\rTextTitleCard\x12\r\n\x05title\x18\x01 \x01(\t\"i\n\x16TimelineEventImageCard\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"j\n\x1aTimelineEventImagetextCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\"\xf8\x01\n\x19TimelineEventResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tposition1\x18\x04 \x01(\t\x12\x11\n\tposition2\x18\x05 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x07 \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x08 \x01(\t\"V\n\x15TimelineEventTextCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"!\n\x10TimelineHeadCard\x12\r\n\x05stage\x18\x01 \x01(\t\"R\n\x10TimelineMoreCard\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x19\n\x11supernatant_title\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t\"R\n\x19TimelineSupernatantParams\x12\x12\n\nlast_index\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\"\x8b\x01\n\x16TimelineSupernatantReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x44\n\x06params\x18\x02 \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineSupernatantParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"`\n\x17TimelineSupernatantResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x12\n\nlast_index\x18\x02 \x01(\x03\"\xce\x04\n\x12TimelineUnfoldCard\x12\x13\n\x0bunfold_text\x18\x01 \x01(\t\x12\x11\n\tfold_text\x18\x02 \x01(\t\x12\x41\n\x05\x63\x61rds\x18\x03 \x03(\x0b\x32\x32.bilibili.app.nativeact.v1.TimelineUnfoldCard.Card\x1a\xcc\x03\n\x04\x43\x61rd\x12I\n\x12timeline_head_card\x18\x01 \x01(\x0b\x32+.bilibili.app.nativeact.v1.TimelineHeadCardH\x00\x12T\n\x18timeline_event_text_card\x18\x02 \x01(\x0b\x32\x30.bilibili.app.nativeact.v1.TimelineEventTextCardH\x00\x12V\n\x19timeline_event_image_card\x18\x03 \x01(\x0b\x32\x31.bilibili.app.nativeact.v1.TimelineEventImageCardH\x00\x12^\n\x1dtimeline_event_imagetext_card\x18\x04 \x01(\x0b\x32\x35.bilibili.app.nativeact.v1.TimelineEventImagetextCardH\x00\x12\\\n\x1ctimeline_event_resource_card\x18\x05 \x01(\x0b\x32\x34.bilibili.app.nativeact.v1.TimelineEventResourceCardH\x00\x42\r\n\x0b\x63\x61rd_detail\"\xb8\x02\n\rTopicIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\"\x9f\x01\n\x06TopTab\x12\x11\n\tbg_image1\x18\x01 \x01(\t\x12\x11\n\tbg_image2\x18\x02 \x01(\t\x12\x15\n\rtab_top_color\x18\x03 \x01(\t\x12\x18\n\x10tab_middle_color\x18\x04 \x01(\t\x12\x18\n\x10tab_bottom_color\x18\x05 \x01(\t\x12\x12\n\nfont_color\x18\x06 \x01(\t\x12\x10\n\x08\x62\x61r_type\x18\x07 \x01(\x03\"\x87\x03\n\tVideoCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x03 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x36\n\x06rights\x18\x08 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoRights\x12=\n\tdimension\x18\t \x01(\x0b\x32*.bilibili.app.nativeact.v1.PlayerDimension\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"h\n\rVideoMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"Y\n\x0bVideoParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"o\n\x08VideoReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\">\n\tVideoResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"F\n\x0bVideoRights\x12\x0f\n\x07ugc_pay\x18\x01 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x02 \x01(\x08\x12\x0e\n\x06is_pgc\x18\x03 \x01(\x08\"\xf5\x01\n\x07VipInfo\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x14\n\x0cvip_pay_type\x18\x04 \x01(\x05\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x32\n\x05label\x18\x06 \x01(\x0b\x32#.bilibili.app.nativeact.v1.VipLabel\x12\x18\n\x10\x61vatar_subscript\x18\x07 \x01(\x05\x12\x16\n\x0enickname_color\x18\x08 \x01(\t\x12\x0c\n\x04role\x18\t \x01(\x03\x12\x1c\n\x14\x61vatar_subscript_url\x18\n \x01(\t\"\x89\x01\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x13\n\x0blabel_theme\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x10\n\x08\x62g_style\x18\x06 \x01(\x05\x12\x10\n\x08\x62g_color\x18\x07 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x08 \x01(\t\"\xe1\x01\n\nVoteButton\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12\x12\n\ndone_image\x18\x02 \x01(\t\x12\x14\n\x0cundone_image\x18\x03 \x01(\t\x12\x11\n\thas_voted\x18\x04 \x01(\x08\x12:\n\x0bmessage_box\x18\x05 \x01(\x0b\x32%.bilibili.app.nativeact.v1.MessageBox\x12\x13\n\x0bvote_params\x18\x06 \x01(\t\x12\x16\n\x0esource_item_id\x18\x07 \x01(\x03\"\xff\x01\n\x08VoteCard\x12\x36\n\x08\x62g_image\x18\x01 \x01(\x0b\x32$.bilibili.app.nativeact.v1.SizeImage\x12\x12\n\noption_num\x18\x02 \x01(\x03\x12\x36\n\x07\x62uttons\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.VoteButton\x12\x34\n\x08left_num\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.VoteNum\x12\x39\n\x08progress\x18\x05 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.VoteProgress\"E\n\x07VoteNum\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12\x0b\n\x03num\x18\x02 \x01(\x03\"\\\n\nVoteParams\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0b\n\x03sid\x18\x02 \x01(\x03\x12\x0b\n\x03gid\x18\x03 \x01(\x03\x12\x16\n\x0esource_item_id\x18\x04 \x01(\x03\x12\x0c\n\x04type\x18\x05 \x01(\t\"\x8b\x02\n\x0cVoteProgress\x12-\n\x04\x61rea\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.nativeact.v1.Area\x12;\n\x05style\x18\x02 \x01(\x0e\x32,.bilibili.app.nativeact.v1.VoteProgressStyle\x12G\n\x05items\x18\x03 \x03(\x0b\x32\x38.bilibili.app.nativeact.v1.VoteProgress.VoteProgressItem\x1a\x46\n\x10VoteProgressItem\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x16\n\x0esource_item_id\x18\x03 \x01(\x03\"T\n\x07VoteReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.bilibili.app.nativeact.v1.VoteParams\"G\n\x08VoteResp\x12\x13\n\x0bvote_params\x18\x01 \x01(\t\x12\x10\n\x08left_num\x18\x02 \x01(\x03\x12\x14\n\x0c\x63\x61n_vote_num\x18\x03 \x01(\x03*+\n\nActionType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x06\n\x02\x44o\x10\x01\x12\x08\n\x04Undo\x10\x02*\'\n\x0eMessageBoxType\x12\n\n\x06\x44ialog\x10\x00\x12\t\n\x05Toast\x10\x01*>\n\x0bProgressBar\x12\x0f\n\x0bPBarDefault\x10\x00\x12\r\n\tPBarColor\x10\x01\x12\x0f\n\x0bPBarTexture\x10\x02*A\n\x0cProgressSlot\x12\x10\n\x0cPSlotDefault\x10\x00\x12\x10\n\x0cPSlotOutline\x10\x01\x12\r\n\tPSlotFill\x10\x02*X\n\rProgressStyle\x12\x11\n\rPStyleDefault\x10\x00\x12\x0f\n\x0bPStyleRound\x10\x01\x12\x13\n\x0fPStyleRectangle\x10\x02\x12\x0e\n\nPStyleNode\x10\x03*A\n\x0cRedirectType\x12\x11\n\rRtTypeDefault\x10\x00\x12\x0f\n\x0bRtTypeSpace\x10\x01\x12\r\n\tRtTypeUri\x10\x02*4\n\x0bReserveGoto\x12\x0b\n\x07Reserve\x10\x00\x12\x0c\n\x08Redirect\x10\x01\x12\n\n\x06Unable\x10\x02*E\n\x08TabStyle\x12\x13\n\x0fTabStyleDefault\x10\x00\x12\x11\n\rTabStyleColor\x10\x01\x12\x11\n\rTabStyleImage\x10\x02*M\n\x11VoteProgressStyle\x12\x12\n\x0eVPStyleDefault\x10\x00\x12\x11\n\rVPStyleCircle\x10\x01\x12\x11\n\rVPStyleSquare\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.nativeact.v1.nativeact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIONTYPE']._serialized_start=21410
  _globals['_ACTIONTYPE']._serialized_end=21453
  _globals['_MESSAGEBOXTYPE']._serialized_start=21455
  _globals['_MESSAGEBOXTYPE']._serialized_end=21494
  _globals['_PROGRESSBAR']._serialized_start=21496
  _globals['_PROGRESSBAR']._serialized_end=21558
  _globals['_PROGRESSSLOT']._serialized_start=21560
  _globals['_PROGRESSSLOT']._serialized_end=21625
  _globals['_PROGRESSSTYLE']._serialized_start=21627
  _globals['_PROGRESSSTYLE']._serialized_end=21715
  _globals['_REDIRECTTYPE']._serialized_start=21717
  _globals['_REDIRECTTYPE']._serialized_end=21782
  _globals['_RESERVEGOTO']._serialized_start=21784
  _globals['_RESERVEGOTO']._serialized_end=21836
  _globals['_TABSTYLE']._serialized_start=21838
  _globals['_TABSTYLE']._serialized_end=21907
  _globals['_VOTEPROGRESSSTYLE']._serialized_start=21909
  _globals['_VOTEPROGRESSSTYLE']._serialized_end=21986
  _globals['_AREA']._serialized_start=188
  _globals['_AREA']._serialized_end=261
  _globals['_BADGE']._serialized_start=263
  _globals['_BADGE']._serialized_end=326
  _globals['_CAROUSELIMGCARD']._serialized_start=328
  _globals['_CAROUSELIMGCARD']._serialized_end=428
  _globals['_CAROUSELIMGITEM']._serialized_start=431
  _globals['_CAROUSELIMGITEM']._serialized_end=575
  _globals['_CAROUSELWORDCARD']._serialized_start=577
  _globals['_CAROUSELWORDCARD']._serialized_end=699
  _globals['_CAROUSELWORDITEM']._serialized_start=701
  _globals['_CAROUSELWORDITEM']._serialized_end=736
  _globals['_COLOR']._serialized_start=739
  _globals['_COLOR']._serialized_end=1524
  _globals['_DYNAMICACTMORECARD']._serialized_start=1526
  _globals['_DYNAMICACTMORECARD']._serialized_end=1635
  _globals['_DYNAMICCARD']._serialized_start=1637
  _globals['_DYNAMICCARD']._serialized_end=1705
  _globals['_DYNAMICMORECARD']._serialized_start=1707
  _globals['_DYNAMICMORECARD']._serialized_end=1813
  _globals['_DYNAMICPARAMS']._serialized_start=1816
  _globals['_DYNAMICPARAMS']._serialized_end=1948
  _globals['_DYNAMICREQ']._serialized_start=1951
  _globals['_DYNAMICREQ']._serialized_end=2198
  _globals['_DYNAMICRESP']._serialized_start=2200
  _globals['_DYNAMICRESP']._serialized_end=2264
  _globals['_EDITORPARAMS']._serialized_start=2266
  _globals['_EDITORPARAMS']._serialized_end=2315
  _globals['_EDITORRECOMMENDCARD']._serialized_start=2318
  _globals['_EDITORRECOMMENDCARD']._serialized_end=2824
  _globals['_EDITORREQ']._serialized_start=2826
  _globals['_EDITORREQ']._serialized_end=2939
  _globals['_EDITORRESP']._serialized_start=2941
  _globals['_EDITORRESP']._serialized_end=3004
  _globals['_FOLLOWOGVPARAMS']._serialized_start=3006
  _globals['_FOLLOWOGVPARAMS']._serialized_end=3097
  _globals['_FOLLOWOGVREQ']._serialized_start=3099
  _globals['_FOLLOWOGVREQ']._serialized_end=3193
  _globals['_FOLLOWOGVRLY']._serialized_start=3195
  _globals['_FOLLOWOGVRLY']._serialized_end=3232
  _globals['_GAMECARD']._serialized_start=3234
  _globals['_GAMECARD']._serialized_end=3322
  _globals['_HEADERCARD']._serialized_start=3325
  _globals['_HEADERCARD']._serialized_end=3540
  _globals['_ICONCARD']._serialized_start=3542
  _globals['_ICONCARD']._serialized_end=3604
  _globals['_ICONITEM']._serialized_start=3606
  _globals['_ICONITEM']._serialized_end=3659
  _globals['_IMAGETITLECARD']._serialized_start=3661
  _globals['_IMAGETITLECARD']._serialized_end=3692
  _globals['_INDEXREQ']._serialized_start=3695
  _globals['_INDEXREQ']._serialized_end=4045
  _globals['_INLINEINDEXREQ']._serialized_start=4048
  _globals['_INLINEINDEXREQ']._serialized_end=4236
  _globals['_LAYERDYNAMIC']._serialized_start=4238
  _globals['_LAYERDYNAMIC']._serialized_end=4322
  _globals['_LIVECARD']._serialized_start=4324
  _globals['_LIVECARD']._serialized_end=4406
  _globals['_LIVEITEM']._serialized_start=4409
  _globals['_LIVEITEM']._serialized_end=4786
  _globals['_LIVEWATCHEDSHOW']._serialized_start=4788
  _globals['_LIVEWATCHEDSHOW']._serialized_end=4911
  _globals['_MESSAGEBOX']._serialized_start=4914
  _globals['_MESSAGEBOX']._serialized_end=5100
  _globals['_MODULE']._serialized_start=5103
  _globals['_MODULE']._serialized_end=5408
  _globals['_MODULEITEM']._serialized_start=5411
  _globals['_MODULEITEM']._serialized_end=9535
  _globals['_MODULEITEM_CARDDETAILCASE']._serialized_start=8538
  _globals['_MODULEITEM_CARDDETAILCASE']._serialized_end=9520
  _globals['_NAVIGATIONCARD']._serialized_start=9537
  _globals['_NAVIGATIONCARD']._serialized_end=9611
  _globals['_NAVIGATIONITEM']._serialized_start=9613
  _globals['_NAVIGATIONITEM']._serialized_end=9663
  _globals['_NEWACTAWARD']._serialized_start=9665
  _globals['_NEWACTAWARD']._serialized_end=9752
  _globals['_NEWACTAWARDITEM']._serialized_start=9754
  _globals['_NEWACTAWARDITEM']._serialized_end=9803
  _globals['_NEWACTFEATURE']._serialized_start=9805
  _globals['_NEWACTFEATURE']._serialized_end=9856
  _globals['_NEWACTHEADER']._serialized_start=9859
  _globals['_NEWACTHEADER']._serialized_end=10069
  _globals['_NEWACTSTATEMENTITEM']._serialized_start=10071
  _globals['_NEWACTSTATEMENTITEM']._serialized_end=10124
  _globals['_NEWACTSTATEMENT']._serialized_start=10126
  _globals['_NEWACTSTATEMENT']._serialized_end=10221
  _globals['_OFFICIALINFO']._serialized_start=10223
  _globals['_OFFICIALINFO']._serialized_end=10294
  _globals['_OGVFOLLOWBUTTON']._serialized_start=10297
  _globals['_OGVFOLLOWBUTTON']._serialized_end=10446
  _globals['_OGVMORECARD']._serialized_start=10448
  _globals['_OGVMORECARD']._serialized_end=10525
  _globals['_OGVONECARD']._serialized_start=10528
  _globals['_OGVONECARD']._serialized_end=10932
  _globals['_OGVSUPERNATANTPARAMS']._serialized_start=10934
  _globals['_OGVSUPERNATANTPARAMS']._serialized_end=11011
  _globals['_OGVSUPERNATANTREQ']._serialized_start=11014
  _globals['_OGVSUPERNATANTREQ']._serialized_end=11143
  _globals['_OGVSUPERNATANTRESP']._serialized_start=11145
  _globals['_OGVSUPERNATANTRESP']._serialized_end=11236
  _globals['_OGVTHREECARD']._serialized_start=11239
  _globals['_OGVTHREECARD']._serialized_end=11537
  _globals['_PAGERESP']._serialized_start=11540
  _globals['_PAGERESP']._serialized_end=12069
  _globals['_PAGESHARE']._serialized_start=12072
  _globals['_PAGESHARE']._serialized_end=12269
  _globals['_PARTICIPATIONCARD']._serialized_start=12271
  _globals['_PARTICIPATIONCARD']._serialized_end=12394
  _globals['_PARTICIPATIONCARDITEM']._serialized_start=12396
  _globals['_PARTICIPATIONCARDITEM']._serialized_end=12476
  _globals['_PLAYERDIMENSION']._serialized_start=12478
  _globals['_PLAYERDIMENSION']._serialized_end=12542
  _globals['_PROGRESSCARD']._serialized_start=12545
  _globals['_PROGRESSCARD']._serialized_end=12847
  _globals['_PROGRESSEVENT']._serialized_start=12849
  _globals['_PROGRESSEVENT']._serialized_end=12942
  _globals['_PROGRESSEVENTITEM']._serialized_start=12944
  _globals['_PROGRESSEVENTITEM']._serialized_end=13064
  _globals['_PROGRESSNODE']._serialized_start=13066
  _globals['_PROGRESSNODE']._serialized_end=13128
  _globals['_PROGRESSREQ']._serialized_start=13130
  _globals['_PROGRESSREQ']._serialized_end=13160
  _globals['_PROGRESSRLY']._serialized_start=13162
  _globals['_PROGRESSRLY']._serialized_end=13232
  _globals['_RCMDCARD']._serialized_start=13235
  _globals['_RCMDCARD']._serialized_end=13527
  _globals['_RCMDVERTICALCARD']._serialized_start=13529
  _globals['_RCMDVERTICALCARD']._serialized_end=13599
  _globals['_RELATIVEACTCAPSULECARD']._serialized_start=13601
  _globals['_RELATIVEACTCAPSULECARD']._serialized_end=13706
  _globals['_RELATIVEACTCAPSULEITEM']._serialized_start=13708
  _globals['_RELATIVEACTCAPSULEITEM']._serialized_end=13777
  _globals['_RELATIVEACTCARD']._serialized_start=13779
  _globals['_RELATIVEACTCARD']._serialized_end=13853
  _globals['_REPLYCARD']._serialized_start=13855
  _globals['_REPLYCARD']._serialized_end=13898
  _globals['_REPORTDIC']._serialized_start=13901
  _globals['_REPORTDIC']._serialized_end=14070
  _globals['_RESERVEBUTTON']._serialized_start=14073
  _globals['_RESERVEBUTTON']._serialized_end=14333
  _globals['_RESERVECARD']._serialized_start=14336
  _globals['_RESERVECARD']._serialized_end=14563
  _globals['_RESERVEPARAMS']._serialized_start=14565
  _globals['_RESERVEPARAMS']._serialized_end=14609
  _globals['_RESERVEREQ']._serialized_start=14611
  _globals['_RESERVEREQ']._serialized_end=14701
  _globals['_RESERVERLY']._serialized_start=14703
  _globals['_RESERVERLY']._serialized_end=14739
  _globals['_RESOURCECARD']._serialized_start=14742
  _globals['_RESOURCECARD']._serialized_end=15069
  _globals['_RESOURCEMORECARD']._serialized_start=15071
  _globals['_RESOURCEMORECARD']._serialized_end=15178
  _globals['_RESOURCEPARAMS']._serialized_start=15180
  _globals['_RESOURCEPARAMS']._serialized_end=15272
  _globals['_RESOURCEREQ']._serialized_start=15274
  _globals['_RESOURCEREQ']._serialized_end=15391
  _globals['_RESOURCERESP']._serialized_start=15393
  _globals['_RESOURCERESP']._serialized_end=15458
  _globals['_SELECTCARD']._serialized_start=15460
  _globals['_SELECTCARD']._serialized_end=15547
  _globals['_SELECTITEM']._serialized_start=15549
  _globals['_SELECTITEM']._serialized_end=15651
  _globals['_SETTING']._serialized_start=15654
  _globals['_SETTING']._serialized_end=16025
  _globals['_SHARE']._serialized_start=16027
  _globals['_SHARE']._serialized_end=16112
  _globals['_SIZEIMAGE']._serialized_start=16114
  _globals['_SIZEIMAGE']._serialized_end=16171
  _globals['_STATEMENTCARD']._serialized_start=16173
  _globals['_STATEMENTCARD']._serialized_end=16205
  _globals['_SUBPAGEDATA']._serialized_start=16207
  _globals['_SUBPAGEDATA']._serialized_end=16304
  _globals['_SUBPAGETAB']._serialized_start=16306
  _globals['_SUBPAGETAB']._serialized_end=16348
  _globals['_TABCARD']._serialized_start=16351
  _globals['_TABCARD']._serialized_end=16540
  _globals['_TABINDEXREQ']._serialized_start=16543
  _globals['_TABINDEXREQ']._serialized_end=16753
  _globals['_TABITEM']._serialized_start=16756
  _globals['_TABITEM']._serialized_end=16975
  _globals['_TEXTCARD']._serialized_start=16977
  _globals['_TEXTCARD']._serialized_end=17001
  _globals['_TEXTTITLECARD']._serialized_start=17003
  _globals['_TEXTTITLECARD']._serialized_end=17033
  _globals['_TIMELINEEVENTIMAGECARD']._serialized_start=17035
  _globals['_TIMELINEEVENTIMAGECARD']._serialized_end=17140
  _globals['_TIMELINEEVENTIMAGETEXTCARD']._serialized_start=17142
  _globals['_TIMELINEEVENTIMAGETEXTCARD']._serialized_end=17248
  _globals['_TIMELINEEVENTRESOURCECARD']._serialized_start=17251
  _globals['_TIMELINEEVENTRESOURCECARD']._serialized_end=17499
  _globals['_TIMELINEEVENTTEXTCARD']._serialized_start=17501
  _globals['_TIMELINEEVENTTEXTCARD']._serialized_end=17587
  _globals['_TIMELINEHEADCARD']._serialized_start=17589
  _globals['_TIMELINEHEADCARD']._serialized_end=17622
  _globals['_TIMELINEMORECARD']._serialized_start=17624
  _globals['_TIMELINEMORECARD']._serialized_end=17706
  _globals['_TIMELINESUPERNATANTPARAMS']._serialized_start=17708
  _globals['_TIMELINESUPERNATANTPARAMS']._serialized_end=17790
  _globals['_TIMELINESUPERNATANTREQ']._serialized_start=17793
  _globals['_TIMELINESUPERNATANTREQ']._serialized_end=17932
  _globals['_TIMELINESUPERNATANTRESP']._serialized_start=17934
  _globals['_TIMELINESUPERNATANTRESP']._serialized_end=18030
  _globals['_TIMELINEUNFOLDCARD']._serialized_start=18033
  _globals['_TIMELINEUNFOLDCARD']._serialized_end=18623
  _globals['_TIMELINEUNFOLDCARD_CARD']._serialized_start=18163
  _globals['_TIMELINEUNFOLDCARD_CARD']._serialized_end=18623
  _globals['_TOPICINDEXREQ']._serialized_start=18626
  _globals['_TOPICINDEXREQ']._serialized_end=18938
  _globals['_TOPTAB']._serialized_start=18941
  _globals['_TOPTAB']._serialized_end=19100
  _globals['_VIDEOCARD']._serialized_start=19103
  _globals['_VIDEOCARD']._serialized_end=19494
  _globals['_VIDEOMORECARD']._serialized_start=19496
  _globals['_VIDEOMORECARD']._serialized_end=19600
  _globals['_VIDEOPARAMS']._serialized_start=19602
  _globals['_VIDEOPARAMS']._serialized_end=19691
  _globals['_VIDEOREQ']._serialized_start=19693
  _globals['_VIDEOREQ']._serialized_end=19804
  _globals['_VIDEORESP']._serialized_start=19806
  _globals['_VIDEORESP']._serialized_end=19868
  _globals['_VIDEORIGHTS']._serialized_start=19870
  _globals['_VIDEORIGHTS']._serialized_end=19940
  _globals['_VIPINFO']._serialized_start=19943
  _globals['_VIPINFO']._serialized_end=20188
  _globals['_VIPLABEL']._serialized_start=20191
  _globals['_VIPLABEL']._serialized_end=20328
  _globals['_VOTEBUTTON']._serialized_start=20331
  _globals['_VOTEBUTTON']._serialized_end=20556
  _globals['_VOTECARD']._serialized_start=20559
  _globals['_VOTECARD']._serialized_end=20814
  _globals['_VOTENUM']._serialized_start=20816
  _globals['_VOTENUM']._serialized_end=20885
  _globals['_VOTEPARAMS']._serialized_start=20887
  _globals['_VOTEPARAMS']._serialized_end=20979
  _globals['_VOTEPROGRESS']._serialized_start=20982
  _globals['_VOTEPROGRESS']._serialized_end=21249
  _globals['_VOTEPROGRESS_VOTEPROGRESSITEM']._serialized_start=21179
  _globals['_VOTEPROGRESS_VOTEPROGRESSITEM']._serialized_end=21249
  _globals['_VOTEREQ']._serialized_start=21251
  _globals['_VOTEREQ']._serialized_end=21335
  _globals['_VOTERESP']._serialized_start=21337
  _globals['_VOTERESP']._serialized_end=21408
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FawkesReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    FF_FIELD_NUMBER: builtins.int
    config: builtins.str
    """客户端在fawkes系统中对应的已发布最新的config版本号"""
    ff: builtins.str
    """客户端在fawkes系统中对应的已发布最新的ff版本号"""
    def __init__(
        self,
        *,
        config: builtins.str = ...,
        ff: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "ff", b"ff"]) -> None: ...

global___FawkesReply = FawkesReply

@typing_extensions.final
class FawkesReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPKEY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    appkey: builtins.str
    """客户端在fawkes系统的唯一名, 如 `android64`"""
    env: builtins.str
    """客户端在fawkes系统中的环境参数, 如 `prod`"""
    session_id: builtins.str
    """启动id, 8 位 0~9, a~z 组成的字符串"""
    def __init__(
        self,
        *,
        appkey: builtins.str = ...,
        env: builtins.str = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["appkey", b"appkey", "env", b"env", "session_id", b"session_id"]) -> None: ...

global___FawkesReq = FawkesReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.im.type.im_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ENUM_FOLD:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ENUM_FOLDEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_FOLD.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FOLD_NO: _ENUM_FOLD.ValueType  # 0
    """"""
    FOLD_YES: _ENUM_FOLD.ValueType  # 1
    """"""
    FOLD_UNKNOWN: _ENUM_FOLD.ValueType  # 2
    """"""

class ENUM_FOLD(_ENUM_FOLD, metaclass=_ENUM_FOLDEnumTypeWrapper):
    """"""

FOLD_NO: ENUM_FOLD.ValueType  # 0
""""""
FOLD_YES: ENUM_FOLD.ValueType  # 1
""""""
FOLD_UNKNOWN: ENUM_FOLD.ValueType  # 2
""""""
global___ENUM_FOLD = ENUM_FOLD

class _ENUM_UNREAD_TYPE:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ENUM_UNREAD_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_UNREAD_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNREAD_TYPE_ALL: _ENUM_UNREAD_TYPE.ValueType  # 0
    """"""
    UNREAD_TYPE_FOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 1
    """"""
    UNREAD_TYPE_UNFOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 2
    """"""
    UNREAD_TYPE_DUSTBIN: _ENUM_UNREAD_TYPE.ValueType  # 3
    """"""

class ENUM_UNREAD_TYPE(_ENUM_UNREAD_TYPE, metaclass=_ENUM_UNREAD_TYPEEnumTypeWrapper):
    """"""

UNREAD_TYPE_ALL: ENUM_UNREAD_TYPE.ValueType  # 0
""""""
UNREAD_TYPE_FOLLOW: ENUM_UNREAD_TYPE.ValueType  # 1
""""""
UNREAD_TYPE_UNFOLLOW: ENUM_UNREAD_TYPE.ValueType  # 2
""""""
UNREAD_TYPE_DUSTBIN: ENUM_UNREAD_TYPE.ValueType  # 3
""""""
global___ENUM_UNREAD_TYPE = ENUM_UNREAD_TYPE

class _SESSION_TYPE:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SESSION_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SESSION_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _SESSION_TYPE.ValueType  # 0
    """"""
    UN_FOLD_SESSION: _SESSION_TYPE.ValueType  # 1
    """"""
    UN_FOLLOW_SINGLE_SESSION: _SESSION_TYPE.ValueType  # 2
    """"""
    MY_GROUP_SESSION: _SESSION_TYPE.ValueType  # 3
    """"""
    ALL_SESSION: _SESSION_TYPE.ValueType  # 4
    """"""
    DUSTBIN_SESSION: _SESSION_TYPE.ValueType  # 5
    """"""

class SESSION_TYPE(_SESSION_TYPE, metaclass=_SESSION_TYPEEnumTypeWrapper):
    """"""

UNKNOWN: SESSION_TYPE.ValueType  # 0
""""""
UN_FOLD_SESSION: SESSION_TYPE.ValueType  # 1
""""""
UN_FOLLOW_SINGLE_SESSION: SESSION_TYPE.ValueType  # 2
""""""
MY_GROUP_SESSION: SESSION_TYPE.ValueType  # 3
""""""
ALL_SESSION: SESSION_TYPE.ValueType  # 4
""""""
DUSTBIN_SESSION: SESSION_TYPE.ValueType  # 5
""""""
global___SESSION_TYPE = SESSION_TYPE

@typing_extensions.final
class DummyReq(google.protobuf.message.Message):
    """空请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDL_FIELD_NUMBER: builtins.int
    idl: builtins.int
    """"""
    def __init__(
        self,
        *,
        idl: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idl", b"idl"]) -> None: ...

global___DummyReq = DummyReq

@typing_extensions.final
class DummyRsp(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DummyRsp = DummyRsp

@typing_extensions.final
class EmotionInfo(google.protobuf.message.Message):
    """表情资源信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    GIF_URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """表情"""
    url: builtins.str
    """表情url"""
    size: builtins.int
    """表情大小
    0:未知 1:min 2:max
    """
    gif_url: builtins.str
    """gif url"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
        size: builtins.int = ...,
        gif_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gif_url", b"gif_url", "size", b"size", "text", b"text", "url", b"url"]) -> None: ...

global___EmotionInfo = EmotionInfo

@typing_extensions.final
class MsgDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_KEY_FIELD_NUMBER: builtins.int
    SEQNO_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""
    seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        msg_key: builtins.int = ...,
        seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_key", b"msg_key", "seqno", b"seqno"]) -> None: ...

global___MsgDetail = MsgDetail

@typing_extensions.final
class MsgFeedUnreadRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UnreadEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UNREAD_FIELD_NUMBER: builtins.int
    @property
    def unread(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        unread: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread", b"unread"]) -> None: ...

global___MsgFeedUnreadRsp = MsgFeedUnreadRsp

@typing_extensions.final
class ReqAckAssisMsg(google.protobuf.message.Message):
    """更新应援团小助手消息已拉取进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACK_SEQNO_FIELD_NUMBER: builtins.int
    ack_seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        ack_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno", b"ack_seqno"]) -> None: ...

global___ReqAckAssisMsg = ReqAckAssisMsg

@typing_extensions.final
class ReqAckSessions(google.protobuf.message.Message):
    """拉取已读消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    end_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "end_ts", b"end_ts", "size", b"size"]) -> None: ...

global___ReqAckSessions = ReqAckSessions

@typing_extensions.final
class ReqBatRmSess(google.protobuf.message.Message):
    """批量删除会话-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqBatRmSess = ReqBatRmSess

@typing_extensions.final
class ReqCloseClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqCloseClearUnreadUI = ReqCloseClearUnreadUI

@typing_extensions.final
class ReqGetMsg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    MSG_DETAIL_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    @property
    def msg_detail(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgDetail]:
        """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        msg_detail: collections.abc.Iterable[global___MsgDetail] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_detail", b"msg_detail", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqGetMsg = ReqGetMsg

@typing_extensions.final
class ReqGetSessions(google.protobuf.message.Message):
    """拉取会话记录列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UNFOLLOW_FOLD_FIELD_NUMBER: builtins.int
    GROUP_FOLD_FIELD_NUMBER: builtins.int
    SORT_RULE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    end_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    session_type: builtins.int
    """"""
    unfollow_fold: builtins.int
    """"""
    group_fold: builtins.int
    """"""
    sort_rule: builtins.int
    """"""
    teenager_mode: builtins.int
    """青少年模式"""
    lessons_mode: builtins.int
    """课堂模式"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
        session_type: builtins.int = ...,
        unfollow_fold: builtins.int = ...,
        group_fold: builtins.int = ...,
        sort_rule: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "end_ts", b"end_ts", "group_fold", b"group_fold", "lessons_mode", b"lessons_mode", "session_type", b"session_type", "size", b"size", "sort_rule", b"sort_rule", "teenager_mode", b"teenager_mode", "unfollow_fold", b"unfollow_fold"]) -> None: ...

global___ReqGetSessions = ReqGetSessions

@typing_extensions.final
class ReqGetSpecificSessions(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
    def __init__(
        self,
        *,
        talker_sessions: collections.abc.Iterable[global___SimpleSession] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions", b"talker_sessions"]) -> None: ...

global___ReqGetSpecificSessions = ReqGetSpecificSessions

@typing_extensions.final
class ReqGroupAssisMsg(google.protobuf.message.Message):
    """应援团消息助手-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        client_seqno: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno", b"client_seqno", "size", b"size"]) -> None: ...

global___ReqGroupAssisMsg = ReqGroupAssisMsg

@typing_extensions.final
class ReqLiveInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    talker_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqLiveInfo = ReqLiveInfo

@typing_extensions.final
class ReqNewSessions(google.protobuf.message.Message):
    """拉取新消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""
    size: builtins.int
    """"""
    teenager_mode: builtins.int
    """"""
    lessons_mode: builtins.int
    """课堂模式"""
    def __init__(
        self,
        *,
        begin_ts: builtins.int = ...,
        size: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts", b"begin_ts", "lessons_mode", b"lessons_mode", "size", b"size", "teenager_mode", b"teenager_mode"]) -> None: ...

global___ReqNewSessions = ReqNewSessions

@typing_extensions.final
class ReqRelationSync(google.protobuf.message.Message):
    """同步关系-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    client_relation_oplog_seqno: builtins.int
    """客户端当前seqno"""
    def __init__(
        self,
        *,
        client_relation_oplog_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_relation_oplog_seqno", b"client_relation_oplog_seqno"]) -> None: ...

global___ReqRelationSync = ReqRelationSync

@typing_extensions.final
class ReqRemoveSession(google.protobuf.message.Message):
    """删除会话记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqRemoveSession = ReqRemoveSession

@typing_extensions.final
class ReqSendMsg(google.protobuf.message.Message):
    """发送消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    COOKIE2_FIELD_NUMBER: builtins.int
    ERROR_CODE_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> bilireq.grpc.protos.bilibili.im.type.im_pb2.Msg:
        """消息内容"""
    cookie: builtins.str
    """"""
    cookie2: builtins.str
    """"""
    error_code: builtins.int
    """"""
    dev_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        msg: bilireq.grpc.protos.bilibili.im.type.im_pb2.Msg | None = ...,
        cookie: builtins.str = ...,
        cookie2: builtins.str = ...,
        error_code: builtins.int = ...,
        dev_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg", b"msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie", b"cookie", "cookie2", b"cookie2", "dev_id", b"dev_id", "error_code", b"error_code", "msg", b"msg"]) -> None: ...

global___ReqSendMsg = ReqSendMsg

@typing_extensions.final
class ReqSessionDetail(google.protobuf.message.Message):
    """拉取会话详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    uid: builtins.int
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        uid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqSessionDetail = ReqSessionDetail

@typing_extensions.final
class ReqSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESS_IDS_FIELD_NUMBER: builtins.int
    @property
    def sess_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReqSessionDetail]:
        """会话详情请求列表"""
    def __init__(
        self,
        *,
        sess_ids: collections.abc.Iterable[global___ReqSessionDetail] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_ids", b"sess_ids"]) -> None: ...

global___ReqSessionDetails = ReqSessionDetails

@typing_extensions.final
class ReqSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    END_SEQNO_FIELD_NUMBER: builtins.int
    BEGIN_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    end_seqno: builtins.int
    """"""
    begin_seqno: builtins.int
    """"""
    size: builtins.int
    """"""
    order: builtins.int
    """"""
    dev_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        end_seqno: builtins.int = ...,
        begin_seqno: builtins.int = ...,
        size: builtins.int = ...,
        order: builtins.int = ...,
        dev_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_seqno", b"begin_seqno", "dev_id", b"dev_id", "end_seqno", b"end_seqno", "order", b"order", "session_type", b"session_type", "size", b"size", "talker_id", b"talker_id"]) -> None: ...

global___ReqSessionMsg = ReqSessionMsg

@typing_extensions.final
class ReqSetTop(google.protobuf.message.Message):
    """置顶聊天-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    OP_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    op_type: builtins.int
    """
    0:置顶 1:取消置顶
    """
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        op_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["op_type", b"op_type", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqSetTop = ReqSetTop

@typing_extensions.final
class ReqShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    size: builtins.int
    """分页大小 最大20"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size", b"size"]) -> None: ...

global___ReqShareList = ReqShareList

@typing_extensions.final
class ReqShowClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        show_dustbin: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "unread_type", b"unread_type"]) -> None: ...

global___ReqShowClearUnreadUI = ReqShowClearUnreadUI

@typing_extensions.final
class ReqSingleUnread(google.protobuf.message.Message):
    """未读私信数-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    uid: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "uid", b"uid", "unread_type", b"unread_type"]) -> None: ...

global___ReqSingleUnread = ReqSingleUnread

@typing_extensions.final
class ReqSpecificSingleUnread(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
    def __init__(
        self,
        *,
        talker_sessions: collections.abc.Iterable[global___SimpleSession] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions", b"talker_sessions"]) -> None: ...

global___ReqSpecificSingleUnread = ReqSpecificSingleUnread

@typing_extensions.final
class ReqSyncAck(google.protobuf.message.Message):
    """确认同步进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""
    def __init__(
        self,
        *,
        client_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno", b"client_seqno"]) -> None: ...

global___ReqSyncAck = ReqSyncAck

@typing_extensions.final
class ReqTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    SINGLEUNREAD_ON_FIELD_NUMBER: builtins.int
    MSGFEED_ON_FIELD_NUMBER: builtins.int
    SYSUP_ON_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""
    show_unfollow_list: builtins.int
    """"""
    uid: builtins.int
    """"""
    show_dustbin: builtins.int
    """"""
    singleunread_on: builtins.int
    """"""
    msgfeed_on: builtins.int
    """"""
    sysup_on: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
        singleunread_on: builtins.int = ...,
        msgfeed_on: builtins.int = ...,
        sysup_on: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msgfeed_on", b"msgfeed_on", "show_dustbin", b"show_dustbin", "show_unfollow_list", b"show_unfollow_list", "singleunread_on", b"singleunread_on", "sysup_on", b"sysup_on", "uid", b"uid", "unread_type", b"unread_type"]) -> None: ...

global___ReqTotalUnread = ReqTotalUnread

@typing_extensions.final
class ReqUpdateAck(google.protobuf.message.Message):
    """更新已读进度-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    ACK_SEQNO_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""
    session_type: builtins.int
    """会话类型"""
    ack_seqno: builtins.int
    """已读的最大seqno"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        ack_seqno: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno", b"ack_seqno", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___ReqUpdateAck = ReqUpdateAck

@typing_extensions.final
class ReqUpdateIntercept(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    talker_id: builtins.int
    """"""
    status: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "talker_id", b"talker_id", "uid", b"uid"]) -> None: ...

global___ReqUpdateIntercept = ReqUpdateIntercept

@typing_extensions.final
class ReqUpdateTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReqUpdateTotalUnread = ReqUpdateTotalUnread

@typing_extensions.final
class RspCloseClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspCloseClearUnreadUI = RspCloseClearUnreadUI

@typing_extensions.final
class RspGetMsg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
    def __init__(
        self,
        *,
        msg: collections.abc.Iterable[bilibili.im.type.im_pb2.Msg] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg"]) -> None: ...

global___RspGetMsg = RspGetMsg

@typing_extensions.final
class RspLiveInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "live_status", b"live_status"]) -> None: ...

global___RspLiveInfo = RspLiveInfo

@typing_extensions.final
class RspMyGroupUnread(google.protobuf.message.Message):
    """我创建的应援团未读数-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_COUNT_FIELD_NUMBER: builtins.int
    unread_count: builtins.int
    """未读消息数"""
    def __init__(
        self,
        *,
        unread_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread_count", b"unread_count"]) -> None: ...

global___RspMyGroupUnread = RspMyGroupUnread

@typing_extensions.final
class RspRelationSync(google.protobuf.message.Message):
    """同步关系-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_FIELD_NUMBER: builtins.int
    RELATION_LOGS_FIELD_NUMBER: builtins.int
    FRIEND_LIST_FIELD_NUMBER: builtins.int
    SERVER_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    GROUP_LIST_FIELD_NUMBER: builtins.int
    full: builtins.int
    """"""
    @property
    def relation_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.RelationLog]:
        """增量日志"""
    @property
    def friend_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.FriendRelation]:
        """全量列表"""
    server_relation_oplog_seqno: builtins.int
    """服务器端最大的relation seqno"""
    @property
    def group_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.GroupRelation]:
        """全量列表"""
    def __init__(
        self,
        *,
        full: builtins.int = ...,
        relation_logs: collections.abc.Iterable[bilibili.im.type.im_pb2.RelationLog] | None = ...,
        friend_list: collections.abc.Iterable[bilibili.im.type.im_pb2.FriendRelation] | None = ...,
        server_relation_oplog_seqno: builtins.int = ...,
        group_list: collections.abc.Iterable[bilibili.im.type.im_pb2.GroupRelation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["friend_list", b"friend_list", "full", b"full", "group_list", b"group_list", "relation_logs", b"relation_logs", "server_relation_oplog_seqno", b"server_relation_oplog_seqno"]) -> None: ...

global___RspRelationSync = RspRelationSync

@typing_extensions.final
class RspSendMsg(google.protobuf.message.Message):
    """发送消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_KEY_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    MSG_CONTENT_FIELD_NUMBER: builtins.int
    KEY_HIT_INFOS_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""
    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
    msg_content: builtins.str
    """"""
    @property
    def key_hit_infos(self) -> bilireq.grpc.protos.bilibili.im.type.im_pb2.KeyHitInfos:
        """"""
    def __init__(
        self,
        *,
        msg_key: builtins.int = ...,
        e_infos: collections.abc.Iterable[global___EmotionInfo] | None = ...,
        msg_content: builtins.str = ...,
        key_hit_infos: bilireq.grpc.protos.bilibili.im.type.im_pb2.KeyHitInfos | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_hit_infos", b"key_hit_infos"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos", b"e_infos", "key_hit_infos", b"key_hit_infos", "msg_content", b"msg_content", "msg_key", b"msg_key"]) -> None: ...

global___RspSendMsg = RspSendMsg

@typing_extensions.final
class RspSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESS_INFOS_FIELD_NUMBER: builtins.int
    @property
    def sess_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """会话详情列表"""
    def __init__(
        self,
        *,
        sess_infos: collections.abc.Iterable[bilibili.im.type.im_pb2.SessionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_infos", b"sess_infos"]) -> None: ...

global___RspSessionDetails = RspSessionDetails

@typing_extensions.final
class RspSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    MIN_SEQNO_FIELD_NUMBER: builtins.int
    MAX_SEQNO_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
    has_more: builtins.int
    """"""
    min_seqno: builtins.int
    """"""
    max_seqno: builtins.int
    """"""
    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[bilibili.im.type.im_pb2.Msg] | None = ...,
        has_more: builtins.int = ...,
        min_seqno: builtins.int = ...,
        max_seqno: builtins.int = ...,
        e_infos: collections.abc.Iterable[global___EmotionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos", b"e_infos", "has_more", b"has_more", "max_seqno", b"max_seqno", "messages", b"messages", "min_seqno", b"min_seqno"]) -> None: ...

global___RspSessionMsg = RspSessionMsg

@typing_extensions.final
class RspSessions(google.protobuf.message.Message):
    """拉取消息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SystemMsgEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SESSION_LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    ANTI_DISTURB_CLEANING_FIELD_NUMBER: builtins.int
    IS_ADDRESS_LIST_EMPTY_FIELD_NUMBER: builtins.int
    SYSTEM_MSG_FIELD_NUMBER: builtins.int
    SHOW_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """"""
    has_more: builtins.int
    """"""
    anti_disturb_cleaning: builtins.bool
    """标记反垃圾会话是否在清理中"""
    is_address_list_empty: builtins.int
    """当session_list为空时，会返回该字段用于判断通讯录是否为空，1表示空，0表示非空"""
    @property
    def system_msg(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
    show_level: builtins.bool
    """"""
    def __init__(
        self,
        *,
        session_list: collections.abc.Iterable[bilibili.im.type.im_pb2.SessionInfo] | None = ...,
        has_more: builtins.int = ...,
        anti_disturb_cleaning: builtins.bool = ...,
        is_address_list_empty: builtins.int = ...,
        system_msg: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        show_level: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_disturb_cleaning", b"anti_disturb_cleaning", "has_more", b"has_more", "is_address_list_empty", b"is_address_list_empty", "session_list", b"session_list", "show_level", b"show_level", "system_msg", b"system_msg"]) -> None: ...

global___RspSessions = RspSessions

@typing_extensions.final
class RspShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_LIST_FIELD_NUMBER: builtins.int
    ISADDRESSLISTEMPTY_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareSessionInfo]:
        """最近会话列表"""
    IsAddressListEmpty: builtins.int
    """"""
    def __init__(
        self,
        *,
        session_list: collections.abc.Iterable[global___ShareSessionInfo] | None = ...,
        IsAddressListEmpty: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["IsAddressListEmpty", b"IsAddressListEmpty", "session_list", b"session_list"]) -> None: ...

global___RspShareList = RspShareList

@typing_extensions.final
class RspShowClearUnreadUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    display: builtins.bool
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        display: builtins.bool = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display", b"display", "text", b"text"]) -> None: ...

global___RspShowClearUnreadUI = RspShowClearUnreadUI

@typing_extensions.final
class RspSingleUnread(google.protobuf.message.Message):
    """未读私信数-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    BIZ_MSG_UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    BIZ_MSG_FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """未关注用户私信数"""
    follow_unread: builtins.int
    """已关注用户私信数"""
    unfollow_push_msg: builtins.int
    """未关注人列表是否有新业务通知"""
    dustbin_push_msg: builtins.int
    """"""
    dustbin_unread: builtins.int
    """"""
    biz_msg_unfollow_unread: builtins.int
    """"""
    biz_msg_follow_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
        biz_msg_unfollow_unread: builtins.int = ...,
        biz_msg_follow_unread: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_msg_follow_unread", b"biz_msg_follow_unread", "biz_msg_unfollow_unread", b"biz_msg_unfollow_unread", "dustbin_push_msg", b"dustbin_push_msg", "dustbin_unread", b"dustbin_unread", "follow_unread", b"follow_unread", "unfollow_push_msg", b"unfollow_push_msg", "unfollow_unread", b"unfollow_unread"]) -> None: ...

global___RspSingleUnread = RspSingleUnread

@typing_extensions.final
class RspSpecificSingleUnread(google.protobuf.message.Message):
    """-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TalkerUnreadCntEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TALKERUNREADCNT_FIELD_NUMBER: builtins.int
    ALLUNREADCNT_FIELD_NUMBER: builtins.int
    @property
    def talkerUnreadCnt(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """key -> 用户uid, value ->未读数"""
    allUnreadCnt: builtins.int
    """总未读数"""
    def __init__(
        self,
        *,
        talkerUnreadCnt: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        allUnreadCnt: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allUnreadCnt", b"allUnreadCnt", "talkerUnreadCnt", b"talkerUnreadCnt"]) -> None: ...

global___RspSpecificSingleUnread = RspSpecificSingleUnread

@typing_extensions.final
class RspSyncAck(google.protobuf.message.Message):
    """确认同步进度-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspSyncAck = RspSyncAck

@typing_extensions.final
class RspTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_SINGLE_UNREAD_FIELD_NUMBER: builtins.int
    MSG_FEED_UNREAD_FIELD_NUMBER: builtins.int
    SYS_MSG_INTERFACE_LAST_MSG_FIELD_NUMBER: builtins.int
    TOTAL_UNREAD_FIELD_NUMBER: builtins.int
    @property
    def session_single_unread(self) -> global___SessionSingleUnreadRsp:
        """"""
    @property
    def msg_feed_unread(self) -> global___MsgFeedUnreadRsp:
        """"""
    @property
    def sys_msg_interface_last_msg(self) -> global___SysMsgInterfaceLastMsgRsp:
        """"""
    total_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        session_single_unread: global___SessionSingleUnreadRsp | None = ...,
        msg_feed_unread: global___MsgFeedUnreadRsp | None = ...,
        sys_msg_interface_last_msg: global___SysMsgInterfaceLastMsgRsp | None = ...,
        total_unread: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg_feed_unread", b"msg_feed_unread", "session_single_unread", b"session_single_unread", "sys_msg_interface_last_msg", b"sys_msg_interface_last_msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_feed_unread", b"msg_feed_unread", "session_single_unread", b"session_single_unread", "sys_msg_interface_last_msg", b"sys_msg_interface_last_msg", "total_unread", b"total_unread"]) -> None: ...

global___RspTotalUnread = RspTotalUnread

@typing_extensions.final
class RspUpdateTotalUnread(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RspUpdateTotalUnread = RspUpdateTotalUnread

@typing_extensions.final
class SessionSingleUnreadRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """"""
    follow_unread: builtins.int
    """"""
    unfollow_push_msg: builtins.int
    """"""
    dustbin_push_msg: builtins.int
    """"""
    dustbin_unread: builtins.int
    """"""
    def __init__(
        self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dustbin_push_msg", b"dustbin_push_msg", "dustbin_unread", b"dustbin_unread", "follow_unread", b"follow_unread", "unfollow_push_msg", b"unfollow_push_msg", "unfollow_unread", b"unfollow_unread"]) -> None: ...

global___SessionSingleUnreadRsp = SessionSingleUnreadRsp

@typing_extensions.final
class ShareSessionInfo(google.protobuf.message.Message):
    """会话信息，用于私信分享"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    TALKER_UNAME_FIELD_NUMBER: builtins.int
    TALKER_ICON_FIELD_NUMBER: builtins.int
    OFFICIAL_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""
    talker_uname: builtins.str
    """"""
    talker_icon: builtins.str
    """"""
    official_type: builtins.int
    """认证信息
    -1: 无认证 0:个人认证 1:机构认证
    """
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        talker_uname: builtins.str = ...,
        talker_icon: builtins.str = ...,
        official_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["official_type", b"official_type", "talker_icon", b"talker_icon", "talker_id", b"talker_id", "talker_uname", b"talker_uname"]) -> None: ...

global___ShareSessionInfo = ShareSessionInfo

@typing_extensions.final
class SimpleSession(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""
    session_type: builtins.int
    """会话类型"""
    def __init__(
        self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___SimpleSession = SimpleSession

@typing_extensions.final
class SysMsgInterfaceLastMsgRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNREAD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    unread: builtins.int
    """"""
    title: builtins.str
    """"""
    time: builtins.str
    """"""
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        unread: builtins.int = ...,
        title: builtins.str = ...,
        time: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "time", b"time", "title", b"title", "unread", b"unread"]) -> None: ...

global___SysMsgInterfaceLastMsgRsp = SysMsgInterfaceLastMsgRsp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/card/v1/card.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import single_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_single__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/app/card/v1/card.proto\x12\x14\x62ilibili.app.card.v1\x1a!bilibili/app/card/v1/single.proto\"\xc2\x05\n\x04\x43\x61rd\x12<\n\x0esmall_cover_v5\x18\x01 \x01(\x0b\x32\".bilibili.app.card.v1.SmallCoverV5H\x00\x12<\n\x0elarge_cover_v1\x18\x02 \x01(\x0b\x32\".bilibili.app.card.v1.LargeCoverV1H\x00\x12\x41\n\x11three_item_all_v2\x18\x03 \x01(\x0b\x32$.bilibili.app.card.v1.ThreeItemAllV2H\x00\x12:\n\rthree_item_v1\x18\x04 \x01(\x0b\x32!.bilibili.app.card.v1.ThreeItemV1H\x00\x12\x33\n\thot_topic\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.card.v1.HotTopicH\x00\x12;\n\x0fthree_item_h_v5\x18\x06 \x01(\x0b\x32 .bilibili.app.card.v1.DynamicHotH\x00\x12>\n\x0fmiddle_cover_v3\x18\x07 \x01(\x0b\x32#.bilibili.app.card.v1.MiddleCoverV3H\x00\x12<\n\x0elarge_cover_v4\x18\x08 \x01(\x0b\x32\".bilibili.app.card.v1.LargeCoverV4H\x00\x12H\n\x14popular_top_entrance\x18\t \x01(\x0b\x32(.bilibili.app.card.v1.PopularTopEntranceH\x00\x12:\n\rrcmd_one_item\x18\n \x01(\x0b\x32!.bilibili.app.card.v1.RcmdOneItemH\x00\x12\x41\n\x11small_cover_v5_ad\x18\x0b \x01(\x0b\x32$.bilibili.app.card.v1.SmallCoverV5AdH\x00\x42\x06\n\x04itemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.card.v1.card_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CARD']._serialized_start=93
  _globals['_CARD']._serialized_end=799
# @@protoc_insertion_point(module_scope)
